==> react-form-builder-5.8.0.tgz: package/lib/PickerSlider/index.js <==
import { memo } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomSlider from '@s-ui/react-atom-slider';
import MoleculeField from '@s-ui/react-molecule-field';
import { createComponentMemo } from '../prop-types/index.js';
import { jsx as _jsx } from "react/jsx-runtime";

var PickerSlider = function PickerSlider(_ref) {
  var slider = _ref.slider,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      errors = _ref.errors,
      alerts = _ref.alerts;
  var id = slider.id,
      datalist = slider.datalist;
  var className = cx('sui-FormBuilder-field', 'sui-FormBuilder-PickerSlider', "sui-FormBuilder-" + id);
  var min = 0;
  var max = datalist.length - 1;
  var value = datalist.findIndex(function (data) {
    return data.value === slider.value;
  });
  var errorMessages = errors[id];
  var alertMessages = alerts[id];

  var formatter = function formatter(index) {
    return datalist[index].text;
  };

  var handleChange = function handleChange(event, _ref2) {
    var index = _ref2.value;
    onChange(id, datalist[index].value);
  };

  var handleBlur = function handleBlur() {
    return onBlur(id, {
      type: slider.type,
      display: slider.display,
      label: slider.label
    });
  };

  var handleFocus = function handleFocus() {
    return onFocus(id, {
      type: slider.type,
      display: slider.display,
      label: slider.label
    });
  };

  if (slider.hidden) {
    return null;
  }

  return /*#__PURE__*/_jsx("div", {
    className: className,
    children: /*#__PURE__*/_jsx(MoleculeField, {
      name: id,
      label: slider.label,
      helpText: slider.help,
      errorText: errorMessages && errorMessages.join('\n'),
      alertText: alertMessages && alertMessages.join('\n'),
      onChange: handleChange,
      onBlur: handleBlur,
      onFocus: handleFocus,
      children: /*#__PURE__*/_jsx(AtomSlider, {
        id: id,
        value: value,
        min: min,
        max: max,
        valueLabelFormatter: formatter,
        valueLabel: true,
        hideTooltip: true,
        marks: [formatter(min), formatter(max)]
      })
    })
  });
};

PickerSlider.displayName = 'PickerSlider';
export default /*#__PURE__*/memo(PickerSlider, createComponentMemo('slider'));

==> react-form-builder-5.9.0.tgz: package/lib/PickerSlider/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomSlider from '@s-ui/react-atom-slider';
import MoleculeField from '@s-ui/react-molecule-field';
import { createComponentMemo } from '../prop-types/index.js';
import { jsx as _jsx } from "react/jsx-runtime";

var PickerSlider = function PickerSlider(_ref) {
  var slider = _ref.slider,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var id = slider.id,
      datalist = slider.datalist;
  var className = cx('sui-FormBuilder-field', 'sui-FormBuilder-PickerSlider', "sui-FormBuilder-" + id);
  var min = 0;
  var max = datalist.length - 1;
  var value = datalist.findIndex(function (data) {
    return data.value === slider.value;
  });
  var errorMessages = errors[id];
  var alertMessages = alerts[id];

  var formatter = function formatter(index) {
    return datalist[index].text;
  };

  var handleChange = function handleChange(event, _ref2) {
    var index = _ref2.value;
    onChange(id, datalist[index].value);
  };

  var handleBlur = function handleBlur() {
    return onBlur(id, {
      type: slider.type,
      display: slider.display,
      label: slider.label
    });
  };

  var handleFocus = function handleFocus() {
    return onFocus(id, {
      type: slider.type,
      display: slider.display,
      label: slider.label
    });
  };

  if (slider.hidden) {
    return null;
  }

  var errorText = errorMessages && errorMessages.join('\n');
  var alertText = alertMessages && alertMessages.join('\n');
  var helpText = slider.help;
  var marks = [formatter(min), formatter(max)];
  var response = renderer({
    id: slider.id,
    innerProps: _extends({}, slider, {
      helpText: helpText,
      errorText: errorText,
      alertText: alertText,
      value: value,
      min: min,
      max: max,
      marks: marks,
      valueLabelFormatter: formatter,
      onChange: handleChange,
      onBlur: handleBlur,
      onFocus: handleFocus
    })
  });
  if ( /*#__PURE__*/isValidElement(response)) return response;
  return /*#__PURE__*/_jsx("div", {
    className: className,
    children: /*#__PURE__*/_jsx(MoleculeField, {
      name: slider.name || slider.id,
      label: slider.label,
      helpText: helpText,
      errorText: errorText,
      alertText: alertText,
      onChange: handleChange,
      onBlur: handleBlur,
      onFocus: handleFocus,
      children: /*#__PURE__*/_jsx(AtomSlider, _extends({
        id: id,
        value: value,
        min: min,
        max: max,
        valueLabelFormatter: formatter,
        valueLabel: true,
        hideTooltip: true,
        marks: marks
      }, response))
    })
  });
};

PickerSlider.displayName = 'PickerSlider';
export default /*#__PURE__*/memo(PickerSlider, createComponentMemo('slider'));
